@@ -975,11 +975,12 @@ class Askdata(SignUp):
         return ig.normalize_columns(df)
 
 
-    def save_dataset(self, df:pd.DataFrame, workspace: str, dataset_slug="", replace=True, dataset_name="", locale="en", skip_import_values=False):
+    def save_dataset(self, df_input:pd.DataFrame, workspace: str, dataset_slug="", replace=True, dataset_name="", locale="en", skip_import_values=False):
 
+        df = df_input.copy()
         for col in df.columns:
             if (df[col].dtypes == "datetime64[ns]"):
-                df[col] = df[col].astype("str")
+                df[col] = df[col].astype("str").replace("NaT", None)
 
         #df = df.where(pd.notnull(df), None)
         df = self.normalize_columns(df)
