@@ -60,9 +60,9 @@ def get_aircall_calls(token, api_key, #mandatory
     
     records = []
 
-    if total_items >= 9000:
+    if total_items >= 10000:
 
-        print("loop reduced range")
+        print("Range interval reduce as:")
 
 
         day_intervals = []
@@ -95,9 +95,45 @@ def get_aircall_calls(token, api_key, #mandatory
             end_date = (dt.today()-td(days = end)).isoformat()
             # converted to UNIX timefromat 
             end_date = math.trunc(time.mktime(datetime.datetime.strptime(end_date, "%Y-%m-%d").timetuple()))
+            
+            new_link = f'https://{token}:{api_key}@api.aircall.io/v1/calls?from={start_date}&to={end_date}&page=1&per_page=50'
+    
+            new_headers = {'accept': 'application/json'}
+
+            new_response = requests.request("GET", new_link, headers=new_headers)
+
+            new_dati = new_response.json()
+
+            new_total_items = new_dati["meta"]["total"]
+            
+            if new_total_items >= 10000:
+                
+                print("Second range interval reduced as:")
+                
+             
+
+                for new_left in range(start, end, -1):
+                    
+                    print("start {}, end {}".format(new_left, new_left - 1))
+
+                    new_start_date = (dt.today() - td(days = new_left)).isoformat()
+                    
+                    # converted to UNIX timefromat
+                    
+                    new_start_date = math.trunc(time.mktime(datetime.datetime.strptime(new_start_date, "%Y-%m-%d").timetuple()))
+                    
+                    new_end_date = (dt.today() - td(days = new_left - 1)).isoformat()
+                    
+                    new_end_date = math.trunc(time.mktime(datetime.datetime.strptime(new_end_date, "%Y-%m-%d").timetuple()))
+                    
+                    records += run_all_requests(new_start_date, new_end_date, token, api_key)
+             
+           
+            
+            else:
 
 
-            records += run_all_requests(start_date, end_date, token, api_key)
+                records += run_all_requests(start_date, end_date, token, api_key)
 
     else:
 
@@ -154,7 +190,7 @@ def run_all_requests(start_date, end_date, token, api_key):
 
             print("Total number of items", total_items)
 
-        
+        '''
 
         if page%30 == 0: 
             
@@ -163,7 +199,9 @@ def run_all_requests(start_date, end_date, token, api_key):
 
             print(dati["meta"])
 
-
+        '''
+        
+        
         if dati["meta"]["count"] == 0:
             run = False
 
